@@ -21,16 +21,16 @@ setuptools.setup(
     description='A Python wrapper for the Dolby.io REST APIs.',
     long_description=long_description,
     long_description_content_type='text/markdown',
-    license='CC0 1.0 Universal',
-    url='https://github.com/dolbyio-samples/dolbyio-rest-apis-client-python',
+    license='MIT',
+    url='https://github.com/dolbyio/dolbyio-rest-apis-client-python',
     project_urls={
         'Documentation': 'https://docs.dolby.io/communications-apis/reference',
-        'Source': 'https://github.com/dolbyio-samples/dolbyio-rest-apis-client-python',
-        'Bug Tracker': 'https://github.com/dolbyio-samples/dolbyio-rest-apis-client-python/issues',
+        'Source': 'https://github.com/dolbyio/dolbyio-rest-apis-client-python',
+        'Bug Tracker': 'https://github.com/dolbyio/dolbyio-rest-apis-client-python/issues',
     },
     package_dir={'': os.path.join(current_path, 'src')},
     packages=setuptools.find_packages(where=os.path.join(current_path, 'src')),
-    python_requires='>=3.6',
+    python_requires='>=3.7',
     use_scm_version= {
         'local_scheme': 'no-local-version',
         'version_scheme': 'release-branch-semver',
@@ -40,10 +40,9 @@ setuptools.setup(
     ],
     install_requires=requirements,
     classifiers=[
-        'License :: CC0 1.0 Universal (CC0 1.0) Public Domain Dedication',
+        'License :: OSI Approved :: MIT License',
         'Programming Language :: Python',
         'Programming Language :: Python :: 3',
-        'Programming Language :: Python :: 3.6',
         'Programming Language :: Python :: 3.7',
         'Programming Language :: Python :: 3.8',
         'Programming Language :: Python :: 3.9',
